#-----------------------------------------------------------------------------
%{?!dist:	%define	dist	.ok}
%define		app		bluetooth
#-----------------------------------------------------------------------------
Name		:	bluez
Version		:	5.64
Release		:	16.2.0.rel%{?dist}
Summary		:	Bluetooth utilities

Packager	:	Osukiss Project	<build-ok@osukiss.org>

License		:	GPLv3+
URL		:	http://www.bluez.org

Source0		:	%{name}-%{version}.tar.xz
Source1		:	%{name}-ok_addon.tar.gz

#-----------------------------------------------------------------------------
BuildRequires	:	dbus		>= 1.6
BuildRequires	:	eudev-devel
BuildRequires	:	libical
BuildRequires	:	python3-docutils
#-----------------------------------------------------------------------------
%description
BlueZ provides support for the core Bluetooth layers and
protocols. It is flexible, efficient and uses a modular
implementation. It has many interesting features:

 * Complete modular implementation
 * Symmetric multi processing safe
 * Multithreaded data processing
 * Support for multiple Bluetooth devices
 * Real hardware abstraction
 * Standard socket interface to all layers
 * Device and service level security support

Currently BlueZ consists of many separate modules:

 * Bluetooth kernel subsystem core
 * L2CAP and SCO audio kernel layers
 * RFCOMM, BNEP, CMTP and HIDP kernel implementations
 * HCI UART, USB, PCMCIA and virtual device drivers
 * General Bluetooth and SDP libraries and daemons
 * Configuration and testing utilities
 * Protocol decoding and analysis tools

#-----------------------------------------------------------------------------
%files			
%defattr(-,root,root,0755)
%config %{_sysconfdir}/%{name}/*.conf
%config %{_sysconfdir}/dbus-1/system.d/bluetooth.conf
%attr (0744,root,root) %{_sysconfdir}/rc.d/init.d/%{app}
%{_sbindir}/%{app}d
#{_bindir}/bccmd
%{_bindir}/bluemoon
%{_bindir}/%{app}ctl
%{_bindir}/btattach
%{_bindir}/btmon
%{_bindir}/ciptool
%{_bindir}/hciattach
%{_bindir}/hciconfig
%{_bindir}/hcidump
%{_bindir}/hcitool
%{_bindir}/l2ping
%{_bindir}/l2test
%{_bindir}/hex2hcd
%{_bindir}/mpris-proxy
%{_bindir}/rctest
%{_bindir}/rfcomm
%{_bindir}/sdptool
%{_libexecdir}/%{app}/%{app}d
%{_datadir}/zsh/site-functions/_bluetoothctl
%{_mandir}/man1/*.1.gz
%{_mandir}/man8/bluetoothd.8.gz

#-----------------------------------------------------------------------------
%preun
if [ "$1" = 0 ]; then
  %{_sysconfdir}/rc.d/init.d/%{app} stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del %{app}
  (
  /bin/echo -n "%{name}-%{version} has been fully removed on "; date
  ) > %{_var}/log/README-%{name}-removed
  fi

%post
/sbin/chkconfig --add %{app}
%{_sysconfdir}/rc.d/init.d/%{app} condrestart > /dev/null 2>&1 || :

#=============================================================================
%package		libs
Summary		:	Libraries for use in Bluetooth applications

#-----------------------------------------------------------------------------
%description		libs
Libraries for use in Bluetooth applications.

#-----------------------------------------------------------------------------
%files			libs
%license COPYING
%{_libdir}/libbluetooth.so.*

#-----------------------------------------------------------------------------
%postun			libs
/usr/sbin/ldconfig

%post			libs
/usr/sbin/ldconfig


#=============================================================================
%package		libs-devel
Summary		:	Development libraries for Bluetooth applications

#-----------------------------------------------------------------------------
Requires	:	%{name}-libs	=	%{version}-%{release}

#-----------------------------------------------------------------------------
%description		libs-devel
bluez-libs-devel contains development libraries and
headers for use in Bluetooth applications

#-----------------------------------------------------------------------------
%files			libs-devel
%{_includedir}/bluetooth/*.h
%{_libdir}/libbluetooth.so
%{_libdir}/pkgconfig/%{name}.pc
%{_defaultdocdir}/%{name}-%{version}/*.txt

#=============================================================================
%package		cups
Summary		:	CUPS printer backend for Bluetooth printers

#-----------------------------------------------------------------------------
Requires	:	%{name}		=	%{version}-%{release}

#-----------------------------------------------------------------------------
%description		cups
This package contains the CUPS backend

#-----------------------------------------------------------------------------
%files			cups
%{_libdir}/cups/backend/bluetooth

#=============================================================================
%package		obexd
Summary		:	Object Exchange daemon for sharing content

#-----------------------------------------------------------------------------
Requires	:	%{name}		=	%{version}-%{release}
Requires	:	%{name}-libs	=	%{version}-%{release}

#-----------------------------------------------------------------------------
%description		obexd
Object Exchange daemon for sharing files, contacts etc over bluetooth

#-----------------------------------------------------------------------------
%files			obexd
%{_libexecdir}/bluetooth/obexd

#=============================================================================
%prep
%setup -q
tar xf %{SOURCE1}

#-----------------------------------------------------------------------------
#building application
%build

./configure						\
        --prefix=%{_prefix}				\
        --includedir=%{_includedir}			\
	--exec-prefix=%{_exec_prefix}			\
	--libexecdir=%{_libexecdir}			\
        --sysconfdir=%{_sysconfdir}			\
        --sbindir=%{_sbindir}				\
	--mandir=%{_mandir}				\
	--libdir=%{_libdir}				\
	--infodir=%{_infodir}				\
	--localstatedir=%{_var}				\
	--docdir=%{_defaultdocdir}/%{name}-%{version}	\
	--enable-library				\
	--enable-tools					\
	--enable-cups					\
	--enable-library				\
	--enable-deprecated				\
	--enable-shared					\
	--disable-systemd				\
	--disable-static				\
	


%define _smp_mflags -j%(/usr/bin/getconf _NPROCESSORS_ONLN)
%{__make} %{_smp_mflags}

#-----------------------------------------------------------------------------
%clean
%{__rm} -rf %{buildroot}

#-----------------------------------------------------------------------------
#installing program
%install
%{__rm} -rf %{buildroot}

%{__make}						\
	DESTDIR=%{buildroot}				\
	install

#link daemon in the right directory
%{__mkdir_p}						\
	%{buildroot}%{_sbindir}
%{__ln_s}						\
	../libexec/%{app}/%{app}d			\
	%{buildroot}%{_sbindir}

#Install the main configuration file 
%{__mkdir_p}						\
	%{buildroot}%{_sysconfdir}/%{name}
install -m644						\
	src/main.conf					\
	%{name}-ok_addon/*.conf				\
	%{buildroot}%{_sysconfdir}/%{name}

#install the API documentation 
%{__mkdir_p}						\
	%{buildroot}%{_defaultdocdir}/%{name}-%{version}
install  -m644 						\
	doc/*.txt					\
	%{buildroot}%{_defaultdocdir}/%{name}-%{version}

#install the daemon server
%{__mkdir_p}						\
	%{buildroot}%{_sysconfdir}/rc.d/init.d
install -m644						\
	%{name}-ok_addon/%{app}				\
	%{buildroot}%{_sysconfdir}/rc.d/init.d

#To remove libtool library
find 							\
	%{buildroot}%{_libdir}				\
	-name \*.la					\
	-delete

#-----------------------------------------------------------------------------
%changelog
